@@ -14,6 +14,7 @@ cFemonConfig femonConfig;
 cFemonConfig::cFemonConfig(void)
 {
   hidemenu       = 0;
+  usesinglearea  = 0;
   displaymode    = 0;
   skin           = 0;
   theme          = 0;
@@ -61,6 +62,18 @@ const cFemonTheme femonTheme[eFemonThemeMaxNumber] =
     0xFFFFEE00, // clrYellow
     0xFF33CC33, // clrGreen
   },
+  {
+    // eFemonThemeSTTNG
+    4,          // bpp
+    0x7F000000, // clrBackground
+    0xFFFCC024, // clrTitleBackground
+    0xFF000000, // clrTitleText
+    0xFF00FCFC, // clrActiveText
+    0xFFFCC024, // clrInactiveText
+    0xFFFC1414, // clrRed
+    0xFFFCC024, // clrYellow
+    0xFF24FC24, // clrGreen
+  },
   {
     // eFemonThemeDeepBlue
     4,          // bpp
